Learn R Programming

Correlplot (version 1.1.3)

achievement: Psychological Variables and Academic Performance

Description

The data set contains psychological measures and academic achievements of 600 college freshmen. This is a classic example data set in multivariate analysis. The data consists of three psychological variables: locus of control, self concept and motivation; four acadamic variables: read, write, math, science and the demographic variables: female.

Usage

data("achievement")

Arguments

Format

A data frame with 600 observations on the following 8 variables.

locus

Locus of control

self

Self concept

motivation

Motivation

read

Standarized test score

write

Standarized test score

math

Standarized test score

science

Standarized test score

female

Gender indicator (1=female,0=male)

Examples

Run this code
data(achievement)

Run the code above in your browser using DataLab