The data set contains psychological measures and academic achievements of 600 college freshmen. This is a classic example data set in multivariate analysis. The data consists of three psychological variables: locus of control, self concept and motivation; four acadamic variables: read, write, math, science and the demographic variables: female.